==> jooq-3.6.2-sources.jar: org/jooq/SortField.java <==
/**
 * Copyright (c) 2009-2015, Data Geekery GmbH (http://www.datageekery.com)
 * All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Other licenses:
 * -----------------------------------------------------------------------------
 * Commercial licenses for this work are available. These replace the above
 * ASL 2.0 and offer limited warranties, support, maintenance, and commercial
 * database integrations.
 *
 * For more information, please visit: http://www.jooq.org/licenses
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 */
package org.jooq;


/**
 * A wrapper for a {@link Field} and a {@link SortField}
 *
 * @param <T> The field type
 * @author Lukas Eder
 * @see Field#asc()
 * @see Field#desc()
 */
public interface SortField<T> extends QueryPart {

    /**
     * The name of this sort field
     */
    String getName();

    /**
     * Get the underlying sort order of this sort field
     */
    SortOrder getOrder();

    /**
     * Add a <code>NULLS FIRST</code> clause to this sort field
     */
    @Support
    SortField<T> nullsFirst();

    /**
     * Add a <code>NULLS LAST</code> clause to this sort field
     */
    @Support
    SortField<T> nullsLast();

}

==> jooq-3.11.9-sources.jar: org/jooq/SortField.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Other licenses:
 * -----------------------------------------------------------------------------
 * Commercial licenses for this work are available. These replace the above
 * ASL 2.0 and offer limited warranties, support, maintenance, and commercial
 * database integrations.
 *
 * For more information, please visit: http://www.jooq.org/licenses
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 */
package org.jooq;


/**
 * A wrapper for a {@link Field} and a {@link SortField}
 *
 * @param <T> The field type
 * @author Lukas Eder
 * @see Field#asc()
 * @see Field#desc()
 */
public interface SortField<T> extends OrderField<T> {

    /**
     * The name of this sort field
     */
    String getName();

    /**
     * Get the underlying sort order of this sort field
     */
    SortOrder getOrder();

    /**
     * Add a <code>NULLS FIRST</code> clause to this sort field
     */
    @Support
    SortField<T> nullsFirst();

    /**
     * Add a <code>NULLS LAST</code> clause to this sort field
     */
    @Support
    SortField<T> nullsLast();

}
